BOOST_PP_ARRAY_REVERSE

The BOOST_PP_ARRAY_REVERSE macro reverses the elements in an array.

#### Usage

BOOST_PP_ARRAY_REVERSE(array)

#### Arguments

array
  The array whose elements are to be reversed.

#### Requirements

Header: <boost/preprocessor/array/reverse.hpp>

#### Sample Code

    #include <boost/preprocessor/array/reverse.hpp>

    #define ARRAY (3, (a, b, c))

    BOOST_PP_ARRAY_REVERSE(ARRAY) // expands to (3, (c, b, a))

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)